summaryrefslogtreecommitdiff
path: root/test/PharLap.py
diff options
context:
space:
mode:
authorSteven Knight <knight@baldmt.com>2006-01-21 19:01:06 +0000
committerSteven Knight <knight@baldmt.com>2006-01-21 19:01:06 +0000
commit6fa468d120a536850a6263abd124c4d54eb8fe33 (patch)
tree6923c674148af3f821725a49e3dbc194658d4257 /test/PharLap.py
parent08680181bada82f6a9aa842ceffadf860d914eb4 (diff)
downloadscons-6fa468d120a536850a6263abd124c4d54eb8fe33.tar.gz
Eliminate unnecessary WIN32/Win32/win32 references in tests, too.
Diffstat (limited to 'test/PharLap.py')
-rw-r--r--test/PharLap.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/PharLap.py b/test/PharLap.py
index 56120087..c8353f43 100644
--- a/test/PharLap.py
+++ b/test/PharLap.py
@@ -34,7 +34,7 @@ import time
test = TestSCons.TestSCons()
if sys.platform != 'win32':
- test.skip_test('PharLap is only available on win32; skipping test.\n')
+ test.skip_test('PharLap is only available on Windows; skipping test.\n')
if not test.detect_tool('linkloc'):
test.skip_test("Could not find 'linkloc', skipping test.\n")
@@ -294,7 +294,7 @@ env.Program(target='minasm', source='minasm.asm')
test.run(arguments='.')
# Assume .exe extension...this test is for Win32 only.
test.fail_test(not os.path.exists('minasm.exe'))
test.up_to_date(arguments='.')
@@ -294,7 +294,7 @@ env.Program(target='minasm', source='minasm.asm')
test.run(arguments='.')
-# Assume .exe extension...this test is for Win32 only.
+# Assume .exe extension...this test is for Windows only.
test.fail_test(not os.path.exists('minasm.exe'))
test.up_to_date(arguments='.')